TokenMode

Enum TokenMode 

#[non_exhaustive]
pub enum TokenMode { SendIfRequired, SendAlways, AppService, }
Available on crate feature client-api only.
How the client should handle access tokens when making requests.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


SendIfRequired

Send access token only when the endpoint requires it.



SendAlways

Always send access token to all endpoints.



AppService

Use application service token handling.